//**************************************************************************
//   Copyright (C) 2004-2006 by Petri Damsten
//   petri.damsten@iki.fi
//
//   This program is free software; you can redistribute it and/or modify
//   it under the terms of the GNU General Public License as published by
//   the Free Software Foundation; either version 2 of the License, or
//   (at your option) any later version.
//
//   This program is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//   GNU General Public License for more details.
//
//   You should have received a copy of the GNU General Public License
//   along with this program; if not, write to the
//   Free Software Foundation, Inc.,
//   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
//**************************************************************************
#ifndef TOOLPROPERTIES_H
#define TOOLPROPERTIES_H

#include "ui_toolproperties.h"
#include "tools.h"

class ToolProperties: public KDialog, public Ui::ToolProperties
{
    Q_OBJECT
  public:
    ToolProperties(QWidget *parent = 0);
    virtual ~ToolProperties() {};

    void setData(const ToolItem& item);
    void getData(ToolItem* item);
    void setReadOnly(bool readonly);
};

#endif
